@@ -40,7 +40,7 @@ utils::globalVariables(
     "neighbors", ".submodels", "has_submodel", "max_neighbor", "max_penalty",
     "max_terms", "max_tree", "model", "name", "num_terms", "penalty", "trees",
     "sub_neighbors", ".pred_class", "x", "y", "predictor_indicators",
-    "compute_intercept", "remove_intercept")
+    "compute_intercept", "remove_intercept", "estimate", "term")
 )
 
 # nocov end
