@@ -163,7 +163,8 @@ update.boost_tree <-
            loss_reduction = NULL, sample_size = NULL,
            stop_iter = NULL,
            fresh = FALSE, ...) {
-    update_dot_check(...)
+
+    eng_args <- update_engine_parameters(object$eng_args, ...)
 
     if (!is.null(parameters)) {
       parameters <- check_final_param(parameters)
@@ -185,12 +186,15 @@ update.boost_tree <-
     # TODO make these blocks into a function and document well
     if (fresh) {
       object$args <- args
+      object$eng_args <- eng_args
     } else {
       null_args <- map_lgl(args, null_value)
       if (any(null_args))
         args <- args[!null_args]
       if (length(args) > 0)
         object$args[names(args)] <- args
+      if (length(eng_args) > 0)
+        object$eng_args[names(eng_args)] <- eng_args
     }
 
     new_model_spec(
