@@ -116,7 +116,8 @@ update.decision_tree <-
            parameters = NULL,
            cost_complexity = NULL, tree_depth = NULL, min_n = NULL,
            fresh = FALSE, ...) {
-    update_dot_check(...)
+
+    eng_args <- update_engine_parameters(object$eng_args, ...)
 
     if (!is.null(parameters)) {
       parameters <- check_final_param(parameters)
@@ -131,12 +132,15 @@ update.decision_tree <-
 
     if (fresh) {
       object$args <- args
+      object$eng_args <- eng_args
     } else {
       null_args <- map_lgl(args, null_value)
       if (any(null_args))
         args <- args[!null_args]
       if (length(args) > 0)
         object$args[names(args)] <- args
+      if (length(eng_args) > 0)
+        object$eng_args[names(eng_args)] <- eng_args
     }
 
     new_model_spec(
