@@ -65,6 +65,17 @@ set_fit(
   )
 )
 
+set_encoding(
+  model = "mlp",
+  eng = "keras",
+  mode = "regression",
+  options = list(
+    predictor_indicators = "traditional",
+    compute_intercept = TRUE,
+    remove_intercept = TRUE
+  )
+)
+
 set_fit(
   model = "mlp",
   eng = "keras",
@@ -77,6 +88,17 @@ set_fit(
   )
 )
 
+set_encoding(
+  model = "mlp",
+  eng = "keras",
+  mode = "classification",
+  options = list(
+    predictor_indicators = "traditional",
+    compute_intercept = TRUE,
+    remove_intercept = TRUE
+  )
+)
+
 set_pred(
   model = "mlp",
   eng = "keras",
@@ -191,6 +213,7 @@ set_model_arg(
   func = list(pkg = "dials", fun = "penalty"),
   has_submodel = FALSE
 )
+
 set_model_arg(
   model = "mlp",
   eng = "nnet",
@@ -199,6 +222,7 @@ set_model_arg(
   func = list(pkg = "dials", fun = "epochs"),
   has_submodel = FALSE
 )
+
 set_fit(
   model = "mlp",
   eng = "nnet",
@@ -211,6 +235,17 @@ set_fit(
   )
 )
 
+set_encoding(
+  model = "mlp",
+  eng = "nnet",
+  mode = "regression",
+  options = list(
+    predictor_indicators = "traditional",
+    compute_intercept = TRUE,
+    remove_intercept = TRUE
+  )
+)
+
 set_fit(
   model = "mlp",
   eng = "nnet",
@@ -223,6 +258,17 @@ set_fit(
   )
 )
 
+set_encoding(
+  model = "mlp",
+  eng = "nnet",
+  mode = "classification",
+  options = list(
+    predictor_indicators = "traditional",
+    compute_intercept = TRUE,
+    remove_intercept = TRUE
+  )
+)
+
 set_pred(
   model = "mlp",
   eng = "nnet",
