@@ -96,7 +96,8 @@ update.nearest_neighbor <- function(object,
                                     weight_func = NULL,
                                     dist_power = NULL,
                                     fresh = FALSE, ...) {
-  update_dot_check(...)
+
+  eng_args <- update_engine_parameters(object$eng_args, ...)
 
   if (!is.null(parameters)) {
     parameters <- check_final_param(parameters)
@@ -112,12 +113,15 @@ update.nearest_neighbor <- function(object,
 
   if (fresh) {
     object$args <- args
+    object$eng_args <- eng_args
   } else {
     null_args <- map_lgl(args, null_value)
     if (any(null_args))
       args <- args[!null_args]
     if (length(args) > 0)
       object$args[names(args)] <- args
+    if (length(eng_args) > 0)
+      object$eng_args[names(eng_args)] <- eng_args
   }
 
   new_model_spec(
