@@ -21,6 +21,17 @@ set_fit(
   )
 )
 
+set_encoding(
+  model = "null_model",
+  eng = "parsnip",
+  mode = "regression",
+  options = list(
+    predictor_indicators = "traditional",
+    compute_intercept = FALSE,
+    remove_intercept = FALSE
+  )
+)
+
 set_fit(
   model = "null_model",
   eng = "parsnip",
@@ -33,6 +44,17 @@ set_fit(
   )
 )
 
+set_encoding(
+  model = "null_model",
+  eng = "parsnip",
+  mode = "classification",
+  options = list(
+    predictor_indicators = "traditional",
+    compute_intercept = FALSE,
+    remove_intercept = FALSE
+  )
+)
+
 set_pred(
   model = "null_model",
   eng = "parsnip",
