@@ -110,7 +110,8 @@ update.rand_forest <-
            parameters = NULL,
            mtry = NULL, trees = NULL, min_n = NULL,
            fresh = FALSE, ...) {
-    update_dot_check(...)
+
+    eng_args <- update_engine_parameters(object$eng_args, ...)
 
     if (!is.null(parameters)) {
       parameters <- check_final_param(parameters)
@@ -126,12 +127,15 @@ update.rand_forest <-
     # TODO make these blocks into a function and document well
     if (fresh) {
       object$args <- args
+      object$eng_args <- eng_args
     } else {
       null_args <- map_lgl(args, null_value)
       if (any(null_args))
         args <- args[!null_args]
       if (length(args) > 0)
         object$args[names(args)] <- args
+      if (length(eng_args) > 0)
+        object$eng_args[names(eng_args)] <- eng_args
     }
 
     new_model_spec(
