@@ -109,14 +109,19 @@ test_that('updating', {
   expr1     <- boost_tree() %>% set_engine("xgboost", verbose = 0)
   expr1_exp <- boost_tree(trees = 10) %>% set_engine("xgboost", verbose = 0)
 
-  expr2     <- boost_tree(trees = varying()) %>% set_engine("xgboost")
-  expr2_exp <- boost_tree(trees = varying())  %>% set_engine("xgboost", verbose = 0)
+  expr2     <- boost_tree(trees = varying()) %>% set_engine("C5.0", bands = varying())
+  expr2_exp <- boost_tree(trees = varying())  %>% set_engine("C5.0", bands = 10)
 
   expr3     <- boost_tree(trees = 1, sample_size = varying())
   expr3_exp <- boost_tree(trees = 1)
 
+  expr4     <- boost_tree() %>% set_engine("C5.0", noGlobalPruning = varying())
+  expr4_exp <- boost_tree() %>% set_engine("C5.0", noGlobalPruning = TRUE)
+
   expect_equal(update(expr1, trees = 10), expr1_exp)
+  expect_equal(update(expr2, bands = 10), expr2_exp)
   expect_equal(update(expr3, trees = 1, fresh = TRUE), expr3_exp)
+  expect_equal(update(expr4, noGlobalPruning = TRUE), expr4_exp)
 
   param_tibb <- tibble::tibble(trees = 7, mtry = 1)
   param_list <- as.list(param_tibb)
