@@ -2,6 +2,9 @@ library(testthat)
 context("data conversion")
 library(parsnip)
 
+source(test_path("helper-objects.R"))
+
+hpc <- hpc_data[1:150, c(2:5, 8)]
 
 # to go from lm_object$x results to our format
 format_x_for_test <- function(x, df = TRUE) {
@@ -22,7 +25,13 @@ context("Testing formula -> xy conversion")
 
 test_that("numeric x and y", {
   expected <- lm(mpg ~ ., data = mtcars, x = TRUE, y = TRUE)
-  observed <- parsnip:::convert_form_to_xy_fit(mpg ~ ., data = mtcars)
+  observed <-
+    parsnip:::convert_form_to_xy_fit(
+      mpg ~ .,
+      data = mtcars,
+      indicators = "traditional",
+      remove_intercept = TRUE
+    )
   expect_equal(format_x_for_test(expected$x), observed$x)
   expect_equivalent(mtcars$mpg, observed$y)
   expect_equal(expected$terms, observed$terms)
@@ -31,16 +40,24 @@ test_that("numeric x and y", {
   expect_null(observed$offset)
 
   expect_equal(
-    mtcars[1:6, -1],
-    parsnip:::convert_form_to_xy_new(observed, new_data = head(mtcars))$x
+    mtcars[1:6,-1],
+    parsnip:::convert_form_to_xy_new(
+      observed,
+      new_data = head(mtcars))$x
   )
 })
 
 test_that("numeric x and y, subsetting", {
   expected <- lm(mpg ~ ., data = mtcars, subset = hp > 170,
                  x = TRUE, y = TRUE)
-  observed <- parsnip:::convert_form_to_xy_fit(mpg ~ ., data = mtcars,
-                                               subset = hp > 170)
+  observed <-
+    parsnip:::convert_form_to_xy_fit(
+      mpg ~ .,
+      data = mtcars,
+      subset = hp > 170,
+      indicators = "traditional",
+      remove_intercept = TRUE
+    )
   expect_equal(format_x_for_test(expected$x), observed$x)
   expect_equivalent(mtcars$mpg[mtcars$hp > 170], observed$y)
   expect_equal(expected$terms, observed$terms)
@@ -53,8 +70,14 @@ test_that("numeric x and y, subsetting", {
 test_that("numeric x and y, weights", {
   expected <- lm(mpg ~ . -disp, data = mtcars, weights = disp,
                  x = TRUE, y = TRUE)
-  observed <- parsnip:::convert_form_to_xy_fit(mpg ~ . -disp, data = mtcars,
-                                               weights = disp)
+  observed <-
+    parsnip:::convert_form_to_xy_fit(
+      mpg ~ . - disp,
+      data = mtcars,
+      weights = disp,
+      indicators = "traditional",
+      remove_intercept = TRUE
+    )
   expect_equal(format_x_for_test(expected$x), observed$x)
   expect_equivalent(mtcars$mpg, observed$y)
   expect_equal(expected$terms, observed$terms)
@@ -64,10 +87,21 @@ test_that("numeric x and y, weights", {
 })
 
 test_that("numeric x and y, offset", {
-  expected <- lm(mpg ~ . -disp, data = mtcars, offset = disp,
-                 x = TRUE, y = TRUE)
-  observed <- parsnip:::convert_form_to_xy_fit(mpg ~ . -disp, data = mtcars,
-                                               offset = log(disp))
+  expected <- lm(
+    mpg ~ . - disp,
+    data = mtcars,
+    offset = disp,
+    x = TRUE,
+    y = TRUE
+  )
+  observed <-
+    parsnip:::convert_form_to_xy_fit(
+      mpg ~ . - disp,
+      data = mtcars,
+      offset = log(disp),
+      indicators = "traditional",
+      remove_intercept = TRUE
+    )
   expect_equal(format_x_for_test(expected$x), observed$x)
   expect_equivalent(mtcars$mpg, observed$y)
   expect_equal(expected$terms, observed$terms)
@@ -75,16 +109,24 @@ test_that("numeric x and y, offset", {
   expect_equal(log(mtcars$disp), observed$offset)
   expect_null(observed$weights)
 
-  new_obs <- parsnip:::convert_form_to_xy_new(observed, new_data = mtcars[1:6,])
-  expect_equal(mtcars[1:6,-c(1, 3)], new_obs$x)
+  new_obs <-
+    parsnip:::convert_form_to_xy_new(observed, new_data = mtcars[1:6, ])
+  expect_equal(mtcars[1:6, -c(1, 3)], new_obs$x)
   expect_equal(log(mtcars$disp)[1:6], new_obs$offset)
 })
 
 test_that("numeric x and y, offset in-line", {
-  expected <- lm(mpg ~ cyl + hp +  offset(log(disp)), data = mtcars,
-                 x = TRUE, y = TRUE)
-  observed <- parsnip:::convert_form_to_xy_fit(mpg ~ cyl + hp +  offset(log(disp)),
-                                               data = mtcars)
+  expected <- lm(mpg ~ cyl + hp +  offset(log(disp)),
+                 data = mtcars,
+                 x = TRUE,
+                 y = TRUE)
+  observed <-
+    parsnip:::convert_form_to_xy_fit(
+      mpg ~ cyl + hp +  offset(log(disp)),
+      data = mtcars,
+      indicators = "traditional",
+      remove_intercept = TRUE
+    )
   expect_equal(format_x_for_test(expected$x), observed$x)
   expect_equivalent(mtcars$mpg, observed$y)
   expect_equal(expected$terms, observed$terms)
@@ -92,18 +134,28 @@ test_that("numeric x and y, offset in-line", {
   expect_equal(log(mtcars$disp), observed$offset)
   expect_null(observed$weights)
 
-  new_obs <- parsnip:::convert_form_to_xy_new(observed, new_data = mtcars[1:6,])
+  new_obs <-
+    parsnip:::convert_form_to_xy_new(observed, new_data = mtcars[1:6, ])
   expect_equal(mtcars[1:6, c("cyl", "hp")], new_obs$x)
   expect_equal(log(mtcars$disp)[1:6], new_obs$offset)
 })
 
 
 test_that("numeric x and y, multiple offsets in-line", {
-  expected <- lm(mpg ~ cyl + hp +  offset(log(disp)) + offset(qsec),
-                 data = mtcars,
-                 x = TRUE, y = TRUE)
-  observed <- parsnip:::convert_form_to_xy_fit(mpg ~ cyl + hp +  offset(log(disp)) +
-                                                 offset(qsec), data = mtcars)
+  expected <- lm(
+    mpg ~ cyl + hp +  offset(log(disp)) + offset(qsec),
+    data = mtcars,
+    x = TRUE,
+    y = TRUE
+  )
+  observed <-
+    parsnip:::convert_form_to_xy_fit(
+      mpg ~ cyl + hp +  offset(log(disp)) +
+        offset(qsec),
+      data = mtcars,
+      indicators = "traditional",
+      remove_intercept = TRUE
+    )
   expect_equal(format_x_for_test(expected$x), observed$x)
   expect_equivalent(mtcars$mpg, observed$y)
   expect_equal(expected$terms, observed$terms)
@@ -111,16 +163,25 @@ test_that("numeric x and y, multiple offsets in-line", {
   expect_equal(log(mtcars$disp) + mtcars$qsec, observed$offset)
   expect_null(observed$weights)
 
-  new_obs <- parsnip:::convert_form_to_xy_new(observed, new_data = mtcars[1:6,])
+  new_obs <-
+    parsnip:::convert_form_to_xy_new(observed, new_data = mtcars[1:6, ])
   expect_equal(mtcars[1:6, c("cyl", "hp")], new_obs$x)
   expect_equal(log(mtcars$disp)[1:6] + mtcars$qsec[1:6],
                new_obs$offset)
 })
 
 test_that("numeric x and y, no intercept", {
-  expected <- lm(mpg ~ 0 + ., data = mtcars,
-                 x = TRUE, y = TRUE)
-  observed <- parsnip:::convert_form_to_xy_fit(mpg ~ 0 + ., data = mtcars)
+  expected <- lm(mpg ~ 0 + .,
+                 data = mtcars,
+                 x = TRUE,
+                 y = TRUE)
+  observed <-
+    parsnip:::convert_form_to_xy_fit(
+      mpg ~ 0 + .,
+      data = mtcars,
+      indicators = "traditional",
+      remove_intercept = TRUE
+    )
   expect_equal(format_x_for_test(expected$x), observed$x)
   expect_equivalent(mtcars$mpg, observed$y)
   expect_equal(expected$terms, observed$terms)
@@ -128,17 +189,22 @@ test_that("numeric x and y, no intercept", {
   expect_null(observed$offset)
   expect_null(observed$weights)
 
-  expect_equal(
-    mtcars[1:6, -1],
-    parsnip:::convert_form_to_xy_new(observed, new_data = head(mtcars))$x
-  )
+  expect_equal(mtcars[1:6,-1],
+               parsnip:::convert_form_to_xy_new(observed, new_data = head(mtcars))$x)
 })
 
 test_that("numeric x and y, inline functions", {
-  expected <- lm(log(mpg) ~ hp + poly(wt, 3), data = mtcars,
-                 x = TRUE, y = TRUE)
-  observed <- parsnip:::convert_form_to_xy_fit(log(mpg) ~ hp + poly(wt, 3),
-                                               data = mtcars)
+  expected <- lm(log(mpg) ~ hp + poly(wt, 3),
+                 data = mtcars,
+                 x = TRUE,
+                 y = TRUE)
+  observed <-
+    parsnip:::convert_form_to_xy_fit(
+      log(mpg) ~ hp + poly(wt, 3),
+      data = mtcars,
+      indicators = "traditional",
+      remove_intercept = TRUE
+    )
   expect_equal(format_x_for_test(expected$x), observed$x)
   expect_equivalent(log(mtcars$mpg), observed$y)
   expect_equal(expected$terms, observed$terms)
@@ -154,7 +220,13 @@ test_that("numeric x and y, inline functions", {
 
 test_that("numeric y and mixed x", {
   expected <- lm(rate ~ ., data = Puromycin, x = TRUE, y = TRUE)
-  observed <- parsnip:::convert_form_to_xy_fit(rate ~ ., data = Puromycin)
+  observed <-
+    parsnip:::convert_form_to_xy_fit(
+      rate ~ .,
+      data = Puromycin,
+      indicators = "traditional",
+      remove_intercept = TRUE
+    )
   expect_equal(format_x_for_test(expected$x), observed$x)
   expect_equivalent(Puromycin$rate, observed$y)
   expect_equal(expected$terms, observed$terms)
@@ -168,14 +240,39 @@ test_that("numeric y and mixed x", {
   )
 })
 
+test_that("mixed x, no dummies, compare to a model that does not create dummies", {
+  expected <- rpart::rpart(rate ~ ., data = Puromycin)
+  data_classes <- attr(expected$terms, "dataClasses")[2:3]
+  observed <-
+    parsnip:::convert_form_to_xy_fit(
+      rate ~ .,
+      data = Puromycin,
+      indicators = "none",
+      remove_intercept = TRUE
+    )
+  expect_equal(names(data_classes), names(observed$x))
+  expect_equal(unname(data_classes), c("numeric", "factor"))
+  expect_s3_class(observed$x$state, "factor")
+  expect_equivalent(Puromycin$rate, observed$y)
+  expect_equal(expected$terms, observed$terms)
+
+  expect_null(observed$weights)
+  expect_null(observed$offset)
+})
+
+
 test_that("numeric y and mixed x, omit missing data", {
   expected <- lm(rate ~ ., data = Puromycin_miss, x = TRUE, y = TRUE)
-  observed <- parsnip:::convert_form_to_xy_fit(rate ~ ., data = Puromycin_miss)
+  observed <-
+    parsnip:::convert_form_to_xy_fit(
+      rate ~ .,
+      data = Puromycin_miss,
+      indicators = "traditional",
+      remove_intercept = TRUE
+    )
   expect_equal(format_x_for_test(expected$x), observed$x)
-  expect_equivalent(
-    Puromycin_miss$rate[complete.cases(Puromycin_miss)],
-    observed$y
-  )
+  expect_equivalent(Puromycin_miss$rate[complete.cases(Puromycin_miss)],
+                    observed$y)
   expect_equal(expected$terms, observed$terms)
   expect_equal(expected$xlevels, observed$xlevels)
   expect_null(observed$weights)
@@ -183,8 +280,11 @@ test_that("numeric y and mixed x, omit missing data", {
 
   expect_equal(
     format_x_for_test(model.matrix(expected$terms, head(Puromycin_miss))),
-    parsnip:::convert_form_to_xy_new(observed, new_data = head(Puromycin_miss),
-                                     na.action = na.omit)$x
+    parsnip:::convert_form_to_xy_new(
+      observed,
+      new_data = head(Puromycin_miss),
+      na.action = na.omit
+    )$x
   )
 })
 
@@ -193,30 +293,46 @@ test_that("numeric y and mixed x, include missing data", {
                            data = Puromycin_miss,
                            na.action = na.pass)
   expected <- model.matrix(rate ~ ., frame_obj)
-  observed <- parsnip:::convert_form_to_xy_fit(rate ~ .,
-                                               data = Puromycin_miss,
-                                               na.action = na.pass)
+  observed <- parsnip:::convert_form_to_xy_fit(
+    rate ~ .,
+    data = Puromycin_miss,
+    na.action = na.pass,
+    indicators = "traditional",
+    remove_intercept = TRUE
+  )
   expect_equal(format_x_for_test(expected), observed$x)
 
   expect_equal(
     format_x_for_test(head(expected)),
-    parsnip:::convert_form_to_xy_new(observed, new_data = head(Puromycin_miss),
-                                     na.action = na.pass)$x
+    parsnip:::convert_form_to_xy_new(
+      observed,
+      new_data = head(Puromycin_miss),
+      na.action = na.pass
+    )$x
   )
 })
 
 test_that("numeric y and mixed x, fail missing data", {
   expect_error(
-    parsnip:::convert_form_to_xy_fit(rate ~ .,
-                                     data = Puromycin_miss,
-                                     na.action = na.fail)
+    parsnip:::convert_form_to_xy_fit(
+      rate ~ .,
+      data = Puromycin_miss,
+      na.action = na.fail,
+      indicators = "traditional",
+      remove_intercept = TRUE
+    )
   )
 })
 
 test_that("numeric y and mixed x, no dummies", {
-  expected <- model.frame(rate ~ ., data = Puromycin)[, -1]
+  expected <- model.frame(rate ~ ., data = Puromycin)[,-1]
   observed <-
-    parsnip:::convert_form_to_xy_fit(rate ~ ., data = Puromycin, indicators = FALSE)
+    parsnip:::convert_form_to_xy_fit(
+      rate ~ .,
+      data = Puromycin,
+      indicators = "none",
+      remove_intercept = TRUE
+    )
   expect_equivalent(expected, observed$x)
 
   expect_equal(
@@ -226,9 +342,17 @@ test_that("numeric y and mixed x, no dummies", {
 })
 
 test_that("numeric x and numeric multivariate y", {
-  expected <- lm(cbind(mpg, disp) ~ ., data = mtcars,
-                 x = TRUE, y = TRUE)
-  observed <- parsnip:::convert_form_to_xy_fit(cbind(mpg, disp) ~ ., data = mtcars)
+  expected <- lm(cbind(mpg, disp) ~ .,
+                 data = mtcars,
+                 x = TRUE,
+                 y = TRUE)
+  observed <-
+    parsnip:::convert_form_to_xy_fit(
+      cbind(mpg, disp) ~ .,
+      data = mtcars,
+      indicators = "traditional",
+      remove_intercept = TRUE
+    )
   expect_equal(format_x_for_test(expected$x), observed$x)
   expect_equivalent(mtcars[, c("mpg", "disp")], observed$y)
   expect_equal(expected$terms, observed$terms)
@@ -236,21 +360,19 @@ test_that("numeric x and numeric multivariate y", {
   expect_null(observed$weights)
   expect_null(observed$offset)
 
-  expect_equal(
-    mtcars[1:6, -c(1, 3)],
-    parsnip:::convert_form_to_xy_new(observed, new_data = head(mtcars))$x
-  )
+  expect_equal(mtcars[1:6,-c(1, 3)],
+               parsnip:::convert_form_to_xy_new(observed, new_data = head(mtcars))$x)
 })
 
 test_that("numeric x and factor y", {
   expected <-
     expect_warning(
-      glm(Species ~ ., data = iris, x = TRUE, y = TRUE, family = binomial()
+      glm(class ~ ., data = hpc, x = TRUE, y = TRUE, family = binomial()
       )
     )
-  observed <- parsnip:::convert_form_to_xy_fit(Species ~ ., data = iris)
+  observed <- parsnip:::convert_form_to_xy_fit(class ~ ., data = hpc)
   expect_equal(format_x_for_test(expected$x), observed$x)
-  expect_equivalent(iris$Species, observed$y)
+  expect_equivalent(hpc$class, observed$y)
   expect_equal(expected$terms, observed$terms)
   expect_equal(expected$xlevels, observed$xlevels)
   expect_null(observed$weights)
@@ -258,7 +380,7 @@ test_that("numeric x and factor y", {
 
   expect_equal(
     head(format_x_for_test(expected$x)),
-    parsnip:::convert_form_to_xy_new(observed, new_data = head(iris))$x
+    parsnip:::convert_form_to_xy_new(observed, new_data = head(hpc))$x
   )
 
 })
@@ -267,45 +389,71 @@ test_that("bad args", {
   expect_error(
     parsnip:::convert_form_to_xy_fit(
       mpg ~ ., data = mtcars,
-      composition = "tibble"
+      composition = "tibble",
+      indicators = "traditional",
+      remove_intercept = TRUE
     )
   )
   expect_error(
     parsnip:::convert_form_to_xy_fit(
       mpg ~ ., data = mtcars,
-      weights = letters[1:nrow(mtcars)]
+      weights = letters[1:nrow(mtcars)],
+      indicators = "traditional",
+      remove_intercept = TRUE
     )
   )
   expect_error(
     parsnip:::convert_form_to_xy_fit(
       mpg ~ ., data = mtcars,
-      offset = 1:10
+      offset = 1:10,
+      indicators = "traditional",
+      remove_intercept = TRUE
     )
   )
 })
 
 test_that("numeric x and y, matrix composition", {
   expected <- lm(mpg ~ ., data = mtcars, x = TRUE, y = TRUE)
-  observed <- parsnip:::convert_form_to_xy_fit(mpg ~ ., data = mtcars,
-                                               composition = "matrix")
+  observed <-
+    parsnip:::convert_form_to_xy_fit(
+      mpg ~ .,
+      data = mtcars,
+      composition = "matrix",
+      indicators = "traditional",
+      remove_intercept = TRUE
+    )
   expect_equal(format_x_for_test(expected$x, df = FALSE), observed$x)
   expect_equivalent(mtcars$mpg, observed$y)
 
-  new_obs <- parsnip:::convert_form_to_xy_new(observed, new_data = head(mtcars),
-                                              composition = "matrix")
-  expect_equal(as.matrix(mtcars[1:6, -1]), new_obs$x)
+  new_obs <-
+    parsnip:::convert_form_to_xy_new(observed,
+                                     new_data = head(mtcars),
+                                     composition = "matrix")
+  expect_equal(as.matrix(mtcars[1:6,-1]), new_obs$x)
 })
 
 test_that("numeric x and multivariate y, matrix composition", {
-  expected <- lm(cbind(mpg, cyl) ~ ., data = mtcars, x = TRUE, y = TRUE)
-  observed <- parsnip:::convert_form_to_xy_fit(cbind(mpg, cyl)  ~ ., data = mtcars,
-                                               composition = "matrix")
+  expected <-
+    lm(cbind(mpg, cyl) ~ .,
+       data = mtcars,
+       x = TRUE,
+       y = TRUE)
+  observed <-
+    parsnip:::convert_form_to_xy_fit(
+      cbind(mpg, cyl)  ~ .,
+      data = mtcars,
+      composition = "matrix",
+      indicators = "traditional",
+      remove_intercept = TRUE
+    )
   expect_equal(format_x_for_test(expected$x, df = FALSE), observed$x)
   expect_equivalent(expected$y, observed$y)
 
-  new_obs <- parsnip:::convert_form_to_xy_new(observed, new_data = head(mtcars),
-                                              composition = "matrix")
-  expect_equal(as.matrix(mtcars[1:6, -(1:2)]), new_obs$x)
+  new_obs <-
+    parsnip:::convert_form_to_xy_new(observed,
+                                     new_data = head(mtcars),
+                                     composition = "matrix")
+  expect_equal(as.matrix(mtcars[1:6,-(1:2)]), new_obs$x)
 })
 
 # ------------------------------------------------------------------------------
@@ -313,7 +461,8 @@ test_that("numeric x and multivariate y, matrix composition", {
 context("Testing xy -> formula conversion")
 
 test_that("data frame x, vector y", {
-  observed <- parsnip:::convert_xy_to_form_fit(mtcars[, -1], mtcars$mpg)
+  observed <-
+    parsnip:::convert_xy_to_form_fit(mtcars[, -1], mtcars$mpg, remove_intercept = TRUE)
   expected <- mtcars[, c(2:11, 1)]
   names(expected)[11] <- "..y"
   expect_equal(expected, observed$data)
@@ -321,15 +470,15 @@ test_that("data frame x, vector y", {
   expect_equal(names(mtcars)[-1], observed$x_var)
   expect_null(observed$weights)
 
-  expect_equal(
-    mtcars[1:6, -1],
-    parsnip:::convert_xy_to_form_new(observed, new_data = head(mtcars[,-1]))
-  )
+  expect_equal(mtcars[1:6, -1],
+               parsnip:::convert_xy_to_form_new(observed, new_data = head(mtcars[,-1])))
 })
 
 
 test_that("matrix x, vector y", {
-  observed <- parsnip:::convert_xy_to_form_fit(as.matrix(mtcars[, -1]), mtcars$mpg)
+  observed <-
+    parsnip:::convert_xy_to_form_fit(as.matrix(mtcars[,-1]), mtcars$mpg,
+                                     remove_intercept = TRUE)
   expected <- mtcars[, c(2:11, 1)]
   names(expected)[11] <- "..y"
   expect_equal(expected, observed$data)
@@ -338,14 +487,16 @@ test_that("matrix x, vector y", {
   expect_null(observed$weights)
 
   expect_equal(
-    mtcars[1:6, -1],
-    parsnip:::convert_xy_to_form_new(observed, new_data = as.matrix(mtcars[1:6,-1]))
+    mtcars[1:6,-1],
+    parsnip:::convert_xy_to_form_new(observed, new_data = as.matrix(mtcars[1:6, -1]))
   )
 })
 
 
 test_that("data frame x, 1 col data frame y", {
-  observed <- parsnip:::convert_xy_to_form_fit(mtcars[, -1], mtcars[, "mpg", drop = FALSE])
+  observed <-
+    parsnip:::convert_xy_to_form_fit(mtcars[, -1], mtcars[, "mpg", drop = FALSE],
+                                     remove_intercept = TRUE)
   expected <- mtcars[, c(2:11, 1)]
   expect_equal(expected, observed$data)
   expect_equal(formula("mpg ~ ."), observed$formula)
@@ -356,7 +507,8 @@ test_that("data frame x, 1 col data frame y", {
 test_that("matrix x, 1 col matrix y", {
   observed <-
     parsnip:::convert_xy_to_form_fit(as.matrix(mtcars[,-1]),
-                                     as.matrix(mtcars[, "mpg", drop = FALSE]))
+                                     as.matrix(mtcars[, "mpg", drop = FALSE]),
+                                     remove_intercept = TRUE)
   expected <- mtcars[, c(2:11, 1)]
   expect_equal(expected, observed$data)
   expect_equal(formula("mpg ~ ."), observed$formula)
@@ -365,8 +517,10 @@ test_that("matrix x, 1 col matrix y", {
 })
 
 test_that("matrix x, 1 col data frame y", {
-  observed <- parsnip:::convert_xy_to_form_fit(as.matrix(mtcars[, -1]),
-                                               mtcars[, "mpg", drop = FALSE])
+  observed <-
+    parsnip:::convert_xy_to_form_fit(as.matrix(mtcars[,-1]),
+                                     mtcars[, "mpg", drop = FALSE],
+                                     remove_intercept = TRUE)
   expected <- mtcars[, c(2:11, 1)]
   expect_equal(expected, observed$data)
   expect_equal(formula("mpg ~ ."), observed$formula)
@@ -376,7 +530,9 @@ test_that("matrix x, 1 col data frame y", {
 
 test_that("data frame x, 1 col matrix y", {
   observed <-
-    parsnip:::convert_xy_to_form_fit(mtcars[,-1], as.matrix(mtcars[, "mpg", drop = FALSE]))
+    parsnip:::convert_xy_to_form_fit(mtcars[,-1],
+                                     as.matrix(mtcars[, "mpg", drop = FALSE]),
+                                     remove_intercept = TRUE)
   expected <- mtcars[, c(2:11, 1)]
   expect_equal(expected, observed$data)
   expect_equal(formula("mpg ~ ."), observed$formula)
@@ -385,7 +541,9 @@ test_that("data frame x, 1 col matrix y", {
 })
 
 test_that("data frame x, 2 col data frame y", {
-  observed <- parsnip:::convert_xy_to_form_fit(mtcars[, -(1:2)], mtcars[, 1:2])
+  observed <-
+    parsnip:::convert_xy_to_form_fit(mtcars[,-(1:2)], mtcars[, 1:2],
+                                     remove_intercept = TRUE)
   expected <- mtcars[, c(3:11, 1:2)]
   expect_equal(expected, observed$data)
   expect_equal(formula("cbind(mpg, cyl) ~ ."), observed$formula)
@@ -396,7 +554,8 @@ test_that("data frame x, 2 col data frame y", {
 test_that("matrix x, 2 col matrix y", {
   observed <-
     parsnip:::convert_xy_to_form_fit(as.matrix(mtcars[,-(1:2)]),
-                                     as.matrix(mtcars[, 1:2]))
+                                     as.matrix(mtcars[, 1:2]),
+                                     remove_intercept = TRUE)
   expected <- mtcars[, c(3:11, 1:2)]
   expect_equal(expected, observed$data)
   expect_equal(formula("cbind(mpg, cyl) ~ ."), observed$formula)
@@ -406,7 +565,8 @@ test_that("matrix x, 2 col matrix y", {
 
 test_that("1 col data frame x, 1 col data frame y", {
   observed <- parsnip:::convert_xy_to_form_fit(mtcars[, 2, drop = FALSE],
-                                               mtcars[, 1, drop = FALSE])
+                                               mtcars[, 1, drop = FALSE],
+                                               remove_intercept = TRUE)
   expected <- mtcars[, 2:1]
   expect_equal(expected, observed$data)
   expect_equal(formula("mpg ~ ."), observed$formula)
@@ -419,7 +579,8 @@ test_that("1 col data frame x, 1 col data frame y", {
 test_that("1 col matrix x, 1 col matrix y", {
   observed <- parsnip:::convert_xy_to_form_fit(
     as.matrix(mtcars[, 2, drop = FALSE]),
-    as.matrix(mtcars[, 1, drop = FALSE])
+    as.matrix(mtcars[, 1, drop = FALSE]),
+    remove_intercept = TRUE
   )
   expected <- mtcars[, 2:1]
   expect_equal(expected, observed$data)
@@ -430,32 +591,32 @@ test_that("1 col matrix x, 1 col matrix y", {
 
 
 test_that("matrix x, factor y", {
-  observed <- parsnip:::convert_xy_to_form_fit(as.matrix(iris[, -5]), iris$Species)
-  expected <- iris
+  observed <- parsnip:::convert_xy_to_form_fit(as.matrix(hpc[, -5]), hpc$class)
+  expected <- as.data.frame(hpc)
   names(expected)[5] <- "..y"
   expect_equal(expected, observed$data)
   expect_equal(formula("..y ~ ."), observed$formula)
-  expect_equal(names(iris)[-5], observed$x_var)
+  expect_equal(names(hpc)[-5], observed$x_var)
   expect_null(observed$weights)
 })
 
 test_that("data frame x, factor y", {
-  observed <- parsnip:::convert_xy_to_form_fit(iris[, -5], iris$Species)
-  expected <- iris
+  observed <- parsnip:::convert_xy_to_form_fit(hpc[, -5], hpc$class)
+  expected <- hpc
   names(expected)[5] <- "..y"
   expect_equivalent(expected, observed$data)
   expect_equal(formula("..y ~ ."), observed$formula)
-  expect_equal(names(iris)[-5], observed$x_var)
+  expect_equal(names(hpc)[-5], observed$x_var)
   expect_null(observed$weights)
 })
 
 
 test_that("bad args", {
   expect_error(
-    parsnip:::convert_xy_to_form_fit(mtcars$disp, mtcars$mpg)
+    parsnip:::convert_xy_to_form_fit(mtcars$disp, mtcars$mpg, remove_intercept = TRUE)
   )
   expect_error(
-    parsnip:::convert_xy_to_form_fit(mtcars[, 1:3], mtcars[, 2:5])
+    parsnip:::convert_xy_to_form_fit(mtcars[, 1:3], mtcars[, 2:5], remove_intercept = TRUE)
   )
 })
 
