@@ -99,13 +99,14 @@ test_that('updating', {
   expr1     <- decision_tree() %>% set_engine("rpart", model = FALSE)
   expr1_exp <- decision_tree(cost_complexity = .1) %>% set_engine("rpart", model = FALSE)
 
-  expr2     <- decision_tree(cost_complexity = varying()) %>% set_engine("rpart")
+  expr2     <- decision_tree(cost_complexity = varying()) %>% set_engine("rpart", model = varying())
   expr2_exp <- decision_tree(cost_complexity = varying())  %>% set_engine("rpart", model = FALSE)
 
   expr3     <- decision_tree(cost_complexity = 1, min_n = varying())
   expr3_exp <- decision_tree(cost_complexity = 1)
 
   expect_equal(update(expr1, cost_complexity = .1), expr1_exp)
+  expect_equal(update(expr2, model = FALSE), expr2_exp)
   expect_equal(update(expr3, cost_complexity = 1, fresh = TRUE), expr3_exp)
 
   param_tibb <- tibble::tibble(cost_complexity = 0.1, min_n = 1)
